package rrf.pingauges2;

import android.app.Activity;
import android.content.Intent;
import android.os.Bundle;
import android.support.v7.app.AppCompatActivity;
import android.text.Editable;
import android.text.TextWatcher;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.Button;
import android.widget.EditText;
import android.widget.Spinner;

import java.util.Locale;

/**
 * Created by Robert R. Fenichel on 12/10/2015.
 */
public class Configure extends AppCompatActivity
  {
    private EditText edMaxNomPinOD;
    private EditText edMinNomPinOD;
    private EditText edPinStep;
    private EditText edPinOffset;
    private Spinner  spinPinSizeFormat;

    private static final int reqLoadConfig = 0;
    private static final String PERIOD = ".";
    private static final String MINUS  = "-";

    //landscape layout not needed

    public void onCreate(Bundle SavedState)
      {
        super.onCreate(SavedState);
        setContentView(R.layout.configure);
        dmPinGauges.get(getApplicationContext()).LoadDefaults();

        SetUpRestoreDefaultsButton();
        SetUpLoadConfigButton();

        SetUpMinNomPinODEditBox();
        SetUpMaxNomPinODEditBox();
        SetUpPinStepEditBox();
        SetUpPinOffsetEditBox();

        SetUpFormatSpinner();

        SetUpSaveConfigurationButton();
        LoadUI();
      } // onCreate

    @Override
    public boolean onCreateOptionsMenu(Menu TheMenu)
      { getMenuInflater().inflate(R.menu.configure_menu, TheMenu);
        return super.onCreateOptionsMenu(TheMenu);
      } // onCreateOptionsMenu

    @Override
    public boolean onOptionsItemSelected(MenuItem TheItem)
      {
        switch (TheItem.getItemId())
        {
          case R.id.menuHoleToPins:
            startActivity(new Intent(Configure.this, HoleToPins.class));
            return true;
          case R.id.menuPinsToHole:
            startActivity(new Intent(Configure.this, PinsToHole.class));
            return true;
          case R.id.menuHelp:
            startActivity(new Intent(Configure.this, Help.class));
            return true;
          default:
            return super.onOptionsItemSelected(TheItem);
        } // switch
      } // onOptionsItemSelected

    private void LoadUI()
      {
        edMaxNomPinOD.setText(String.format(Locale.ENGLISH, "       %.3f", dmPinGauges.TheConfiguration.MaxNomPinOD));
        edMinNomPinOD.setText(String.format(Locale.ENGLISH, "       %.3f", dmPinGauges.TheConfiguration.MinNomPinOD));
        edPinOffset.setText(String.format(Locale.ENGLISH, "           %.4f", dmPinGauges.TheConfiguration.PinOffset));
        edPinStep.setText(String.format(Locale.ENGLISH, "       %.3f", dmPinGauges.TheConfiguration.PinStep));

        // From here to the end of this method, the code is hard-bound to the sequence in SetUpFormatSpinner
        if (dmPinGauges.TheConfiguration.PinFormat.equals(".2f"))
          { spinPinSizeFormat.setSelection(3); }
        else if (dmPinGauges.TheConfiguration.PinFormat.equals(".3f"))
          { spinPinSizeFormat.setSelection(0); }
        else if (dmPinGauges.TheConfiguration.PinFormatFactor == 100.0)
          { if (dmPinGauges.TheConfiguration.PinFormat.equals("d"))
              { spinPinSizeFormat.setSelection(4); }
            else
              { spinPinSizeFormat.setSelection(5); }
          }
        else if (dmPinGauges.TheConfiguration.PinFormat.equals("d"))
          { spinPinSizeFormat.setSelection(1); }
        else
          { spinPinSizeFormat.setSelection(2); }
      } // LoadUI

    private void SetPinFormat(String TheFormat, double TheFactor)
      {
        dmPinGauges.TheConfiguration.PinFormat = TheFormat;
        dmPinGauges.TheConfiguration.PinFormatFactor = TheFactor;
      } // SetPinFormat

    private void SetUpFormatSpinner()
      {
        spinPinSizeFormat = (Spinner) findViewById(R.id.spinPinSizeFormat);

        ArrayAdapter<CharSequence> PinSizeAdapter =  ArrayAdapter.createFromResource(this,
                                                                                     R.array.PinFormats,
                                                                                     android.R.layout.simple_list_item_1);
        spinPinSizeFormat.setAdapter(PinSizeAdapter);
        spinPinSizeFormat.setOnItemSelectedListener(new AdapterView.OnItemSelectedListener()
          {
            @Override
            public void onItemSelected(AdapterView<?> parent, View view, int position, long id)
              { switch (position)
                  { case 0:
                      SetPinFormat(".3f",    1.0); break;
                    case 1:
                      SetPinFormat(  "d", 1000.0); break;
                    case 2:
                      SetPinFormat("03d", 1000.0); break;
                    case 3:
                      SetPinFormat(".2f",    1.0); break;
                    case 4:
                      SetPinFormat(  "d",  100.0); break;
                    case 5:
                      SetPinFormat("03d",  100.0); break;
                    default:
                  }
              }
            @Override
            public void onNothingSelected(AdapterView<?> parent)
              { }
          });
        } // SetUpFormatSpinner

    private void SetUpLoadConfigButton()
      {
        Button btnLoadConfiguration = (Button) findViewById(R.id.btnLoadConfiguration);
        btnLoadConfiguration.setOnClickListener(new View.OnClickListener()
          {
            @Override
            public void onClick(View v)
              { startActivityForResult(new Intent(Configure.this, dlgLoadConfig.class), reqLoadConfig); }
          }); // setOnClickListener
        btnLoadConfiguration.setEnabled(dmPinGauges.get(getApplicationContext()).NSavedConfigs() > 0);
      } // SetUpLoadConfigButton

    @Override
    protected void onActivityResult(int requestCode, int resultCode, Intent TheIntent)
      { if (resultCode != Activity.RESULT_OK)
          { return; }
        if (requestCode == reqLoadConfig)
        { LoadUI(); }
      } // onActivityResult

    private void SetUpMaxNomPinODEditBox()
      {
      edMaxNomPinOD = (EditText) findViewById(R.id.edMaxNomPinOD);

      edMaxNomPinOD.addTextChangedListener(new TextWatcher() {
        @Override
        public void beforeTextChanged(CharSequence s, int start, int count, int after) {
        } // before text changed; intentionally null

        @Override
        public void onTextChanged(CharSequence s, int start, int before, int count)
        {
          if (s.toString().trim().length() > 0)
          { dmPinGauges.TheConfiguration.MaxNomPinOD = Float.valueOf(s.toString().trim());}
        } // on change

        @Override
        public void afterTextChanged(Editable s) {
        } // after text changed; intentionally null
      }); // addTextChangedListener
    } // SetUpMaxNomPinODEditBox

    private void SetUpMinNomPinODEditBox()
      {
        edMinNomPinOD = (EditText) findViewById(R.id.edMinNomPinOD);
        edMinNomPinOD.addTextChangedListener(new TextWatcher()
          {
            @Override
            public void beforeTextChanged(CharSequence s, int start, int count, int after)
              { } // before text changed; intentionally null

            @Override
            public void onTextChanged(CharSequence s, int start, int before, int count)
              {
                if (s.toString().trim().length() > 0)
                  { dmPinGauges.TheConfiguration.MinNomPinOD = Float.valueOf(s.toString().trim());}
              } // on change

            @Override
            public void afterTextChanged(Editable s)
              {} // after text changed; intentionally null
          }); // addTextChangedListener
      } // SetUpMinNomPinODEditBox

    private void SetUpPinOffsetEditBox()
      {
        edPinOffset = (EditText) findViewById(R.id.edPinOffset);
        edPinOffset.addTextChangedListener(new TextWatcher()
          {
            @Override
            public void beforeTextChanged(CharSequence s, int start, int count, int after)
              { } // before text changed; intentionally null

            @Override
            public void onTextChanged(CharSequence s, int start, int before, int count)
              {
                String S = s.toString().trim();
                if ((S.length() > 0) && (!S.equals(PERIOD)) && (!S.equals(MINUS)))
                  { dmPinGauges.TheConfiguration.PinOffset = Float.valueOf(s.toString().trim());}
              } // on change

            @Override
            public void afterTextChanged(Editable s)
              { } // after text changed; intentionally null
          }); // addTextChangedListener
      } // SetUpPinOffsetEditBox

    private void SetUpPinStepEditBox()
      {
        edPinStep = (EditText) findViewById(R.id.edPinStep);
        edPinStep.addTextChangedListener(new TextWatcher()
          {
            @Override
            public void beforeTextChanged(CharSequence s, int start, int count, int after)
              {} // before text changed; intentionally null

            @Override
            public void onTextChanged(CharSequence s, int start, int before, int count)
              {
                if (s.toString().trim().length() > 0)
                { dmPinGauges.TheConfiguration.PinStep = Float.valueOf(s.toString().trim());}
              } // on change

            @Override
            public void afterTextChanged(Editable s)
              {} // after text changed; intentionally null
          }); // addTextChangedListener
      } // SetUpPinStepEditBox

    private void SetUpRestoreDefaultsButton()
      {
        Button btnRestoreDefaults = (Button) findViewById(R.id.btnRestoreDefaults);
        btnRestoreDefaults.setOnClickListener(new View.OnClickListener()
          {
            @Override
            public void onClick(View v)
              {
                dmPinGauges.get(getApplicationContext()).LoadDefaults();
                LoadUI();
              } // the listener
          }); // setOnClickListener
      } // SetUpRestoreDefaultsButton

    private void SetUpSaveConfigurationButton()
      {
        Button btnSaveConfiguration = (Button) findViewById(R.id.btnConfSaveConfiguration);
        btnSaveConfiguration.setOnClickListener(new View.OnClickListener()
          {
            @Override
            public void onClick(View v)
              { startActivity(new Intent(Configure.this, dlgSaveConfig.class)); } // the listener
          }); // setOnClickListener
      } // SetUpSaveConfigurationButton

  } // Configure
